#include <cvidef.h>

/*= R3562 3GPP Receiver Test Source Include File ============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __avSG3GPP_HEADER
#define __avSG3GPP_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17              (_VI_ERROR+0x3FFC0811L)  
/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define AVSG3GPP_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC avSG3GPP_Initialize (ViRsrc resourceName, ViBoolean IDQuery,
                                       ViBoolean resetDevice,
                                       ViSession *instrumentHandle);

ViStatus _VI_FUNC avSG3GPP_Set_OutputFrequency (ViSession instrumentHandle,
                                               ViBoolean settingMode,
                                               ViReal64 outputFrequency,
                                               ViInt16 outputChannel,
                                               ViReal64 startFrequency,
                                               ViReal64 channelSpace,
                                               ViInt16 startChannelNumber);

ViStatus _VI_FUNC avSG3GPP_Set_ReferenceLevel (ViSession instrumentHandle,
                                              ViBoolean output,
                                              ViReal64 referenceLevel,
                                              ViReal64 upperLimitLevel,
                                              ViBoolean levelOffset,
                                              ViReal64 levelOffsetValue,
                                              ViInt16 ALCMode);

ViStatus _VI_FUNC avSG3GPP_Set_Modulation (ViSession instrumentHandle,
                                           ViBoolean modulation,
                                           ViInt16 IQTermDirection, 
                                           ViBoolean link);

ViStatus _VI_FUNC avSG3GPP_Set_UpLinkDPDCH (ViSession instrumentHandle,
                                            ViInt16 channelConfiguration,
                                            ViInt16 DPDCHDataPattern,
                                            ViInt16 DTCHData, ViBoolean DTCHFEC,
                                            ViInt16 DTCHCRC, ViInt16 DCCHData,
                                            ViBoolean DCCHFEC, ViInt16 DCCHCRC);

ViStatus _VI_FUNC avSG3GPP_Set_UpLinkDPCCH (ViSession instrumentHandle,
                                            ViInt16 slotFormat,
                                            ViInt16 TFCICodeWord,
                                            ViInt32 FBIBitPattern,
                                            ViInt16 TPCSlotLength,
                                            ViInt16 TPCInsertSlotLength);

ViStatus _VI_FUNC avSG3GPP_set_UpLinkSpreading (ViSession instrumentHandle,
                                                ViInt32 scramblingCode);

ViStatus _VI_FUNC avSG3GPP_Set_UpLinkGainParameters (ViSession instrumentHandle,
                                                     ViInt16 controlSelect,
                                                     ViInt16 DPDCHsGainParameterCode,
                                                     ViInt16 DPCCHsGainParameterCode,
                                                     ViReal64 DPDCHsPowerRate,
                                                     ViReal64 DPCCHsPowerRate);

ViStatus _VI_FUNC avSG3GPP_Set_DownLinkDPCH (ViSession instrumentHandle,
                                             ViInt16 channelConfiguration);

ViStatus _VI_FUNC avSG3GPP_Set_DownLinkDPDCH (ViSession instrumentHandle,
                                              ViInt16 DPDCHDataPattern,
                                              ViInt16 DTCHData,
                                              ViBoolean DTCHFEC, ViInt16 DTCHCRC,
                                              ViInt16 DCCHData,
                        
                                              ViBoolean DCCHFEC, ViInt16 DCCHCRC);

ViStatus _VI_FUNC avSG3GPP_Set_DownLinkDPCCH (ViSession instrumentHandle,
                                              ViInt16 TFCICodeWord,
                                              ViInt16 TPCSlotLength,
                                              ViInt16 TPCInsertSlotLength);

ViStatus _VI_FUNC avSG3GPP_Set_DownLinkSpreading (ViSession instrumentHandle,
                                                  ViInt16 DPCHChannelizationCode,
                                                  ViInt16 scramblingCode);

ViStatus _VI_FUNC avSG3GPP_Set_DownLinkChannelPower (ViSession instrumentHandle,
                                                     ViReal64 CPICHPowerRate,
                                                     ViReal64 PCCPCHPowerRate,
                                                     ViReal64 DPCHPowerRate);

ViStatus _VI_FUNC avSG3GPP_Adjust_ExternalIQ (ViSession instrumentHandle,
                                              ViInt16 ISignalInputGain,
                                              ViInt16 QSignalInputGain,
                                              ViInt16 IQSignalInputPhase,
                                              ViInt16 ISignalOutputGain,
                                              ViInt16 QSignalOutputGain);

ViStatus _VI_FUNC avSG3GPP_StartStop_BERCounter (ViSession instrumentHandle,
                                                 ViBoolean measurement);

ViStatus _VI_FUNC avSG3GPP_Meas_BERCounter (ViSession instrumentHandle,
                                            ViBoolean measurement,
                                            ViBoolean measurementData,
                                            ViInt32 measurementBitLength,
                                            ViBoolean inputClockPolarity,
                                            ViBoolean inputDataPolarity);

ViStatus _VI_FUNC avSG3GPP_Calibration (ViSession instrumentHandle,
                                        ViBoolean calibration,
                                        ViBoolean calibrationCorrection);

ViStatus _VI_FUNC avSG3GPP_Set_ClockTiming (ViSession instrumentHandle,
                                            ViInt16 SYNTHEREFIN,
                                            ViInt16 _10MHzRefSourceAdjustment,
                                            ViInt16 MODTIMEBASEIN,
                                            ViBoolean EXTTRIGCOMMAND,
                                            ViBoolean EXTTRIGPolarity,
                                            ViInt16 EXTTRIGOffset,
                                            ViInt16 CLOCKOUT1Counter,
                                            ViInt16 CLOCKOUT2Counter);

ViStatus _VI_FUNC avSG3GPP_SaveRecall (ViSession instrumentHandle,
                                       ViBoolean operation,
                                       ViInt16 parameterNumber);

ViStatus _VI_FUNC avSG3GPP_StatusByteRegister (ViSession instrumentHandle,
                                               ViBoolean registerMode,
                                               ViInt16 registerValue,
                                               ViInt16 *registerStatus);

ViStatus _VI_FUNC avSG3GPP_ServiceRequest (ViSession instrumentHandle,
                                           ViBoolean serviceRequest);

ViStatus _VI_FUNC avSG3GPP_Clear_StatusByte (ViSession instrumentHandle);

ViStatus _VI_FUNC avSG3GPP_Wait_Execution (ViSession instrumentHandle,
                                           ViInt32 maxWaitTime_sec,
                                           ViBoolean *errorFlag);

ViStatus _VI_FUNC avSG3GPP_Read_BERCounter (ViSession instrumentHandle,
                                            ViReal64 *bitErrorRate);

ViStatus _VI_FUNC avSG3GPP_Read_MeasStatusRegister (ViSession instrumentHandle,
                                                    ViInt16 *measStatusRegister);

ViStatus _VI_FUNC avSG3GPP_SelfTest (ViSession instrumentHandle,
                                     ViInt16 *selfTestResult);

ViStatus _VI_FUNC avSG3GPP_ErrorMessage (ViSession instrumentHandle,
                                         ViStatus statusCode, ViChar message[]);

ViStatus _VI_FUNC avSG3GPP_Reset (ViSession instrumentHandle);

ViStatus _VI_FUNC avSG3GPP_Query_TypeRevision (ViSession instrumentHandle,
                                               ViChar instrumentDriverRevision[],
                                               ViChar firmwareType[],
                                               ViChar firmwareSystemCode[],
                                               ViChar firmwareRevision[]);

ViStatus CVIFUNC avSG3GPP_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
